==> jc-1.4.0.tar.gz: java/lang/reflect/UndeclaredThrowableException.h <==
// public class java.lang.reflect.UndeclaredThrowableException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class aa2ce1553c0fdf62 java_lang_reflect_UndeclaredThrowableException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_reflect_UndeclaredThrowableException_H_
#define _JC_java_lang_reflect_UndeclaredThrowableException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_refs	_jc_java_lang_reflect_UndeclaredThrowableException$sub_refs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs	_jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$refs	_jc_java_lang_reflect_UndeclaredThrowableException$refs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$nonrefs	_jc_java_lang_reflect_UndeclaredThrowableException$nonrefs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$object	_jc_java_lang_reflect_UndeclaredThrowableException$object;

typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$fields_struct	_jc_java_lang_reflect_UndeclaredThrowableException$fields_struct;
typedef const struct _jc_java_lang_reflect_UndeclaredThrowableException$vmethods	_jc_java_lang_reflect_UndeclaredThrowableException$vmethods;
typedef const struct _jc_java_lang_reflect_UndeclaredThrowableException$vtable	_jc_java_lang_reflect_UndeclaredThrowableException$vtable;
typedef const struct _jc_java_lang_reflect_UndeclaredThrowableException$vtype	_jc_java_lang_reflect_UndeclaredThrowableException$vtype;

// Class fields structure
struct _jc_java_lang_reflect_UndeclaredThrowableException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_UndeclaredThrowableException$fields_struct _jc_java_lang_reflect_UndeclaredThrowableException$class_fields;

// Constructors
extern void _jc_java_lang_reflect_UndeclaredThrowableException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_lang_reflect_UndeclaredThrowableException$method$_init$3ba429d9416edd46(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *, struct _jc_java_lang_Throwable$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_UndeclaredThrowableException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *);
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_UndeclaredThrowableException$method$getUndeclaredThrowable$2bb9d188611e37cb(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_UndeclaredThrowableException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_reflect_UndeclaredThrowableException$method_info$getUndeclaredThrowable$2bb9d188611e37cb;

// Virtual methods structure
struct _jc_java_lang_reflect_UndeclaredThrowableException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *);
	struct _jc_java_lang_Throwable$object	*(*getUndeclaredThrowable$2bb9d188611e37cb)(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *);
};

// Vtable
struct _jc_java_lang_reflect_UndeclaredThrowableException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_reflect_UndeclaredThrowableException$vmethods	java_lang_reflect_UndeclaredThrowableException;
};

// Vtype
struct _jc_java_lang_reflect_UndeclaredThrowableException$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_UndeclaredThrowableException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_refs {
	struct _jc_java_lang_Throwable$object	*undeclaredThrowable;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_UndeclaredThrowableException$refs {
    _jc_java_lang_reflect_UndeclaredThrowableException$sub_refs	java_lang_reflect_UndeclaredThrowableException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_UndeclaredThrowableException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs	java_lang_reflect_UndeclaredThrowableException;
};

// Object instance structure
struct _jc_java_lang_reflect_UndeclaredThrowableException$object {
	_jc_java_lang_reflect_UndeclaredThrowableException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_UndeclaredThrowableException$vtype	*vtype;
	_jc_java_lang_reflect_UndeclaredThrowableException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_UndeclaredThrowableException$vtype _jc_java_lang_reflect_UndeclaredThrowableException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_UndeclaredThrowableException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_UndeclaredThrowableException$class_object;

#endif	/* _JC_java_lang_reflect_UndeclaredThrowableException_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/UndeclaredThrowableException.h <==
// public class java.lang.reflect.UndeclaredThrowableException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class aa2ce1553c0fdf62 java_lang_reflect_UndeclaredThrowableException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_reflect_UndeclaredThrowableException_H_
#define _JC_java_lang_reflect_UndeclaredThrowableException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_refs	_jc_java_lang_reflect_UndeclaredThrowableException$sub_refs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs	_jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$refs	_jc_java_lang_reflect_UndeclaredThrowableException$refs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$nonrefs	_jc_java_lang_reflect_UndeclaredThrowableException$nonrefs;
typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$object	_jc_java_lang_reflect_UndeclaredThrowableException$object;

typedef struct _jc_java_lang_reflect_UndeclaredThrowableException$fields_struct	_jc_java_lang_reflect_UndeclaredThrowableException$fields_struct;
typedef const struct _jc_java_lang_reflect_UndeclaredThrowableException$vmethods	_jc_java_lang_reflect_UndeclaredThrowableException$vmethods;
typedef const struct _jc_java_lang_reflect_UndeclaredThrowableException$vtable	_jc_java_lang_reflect_UndeclaredThrowableException$vtable;
typedef const struct _jc_java_lang_reflect_UndeclaredThrowableException$vtype	_jc_java_lang_reflect_UndeclaredThrowableException$vtype;

// Class fields structure
struct _jc_java_lang_reflect_UndeclaredThrowableException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_UndeclaredThrowableException$fields_struct _jc_java_lang_reflect_UndeclaredThrowableException$class_fields;

// Constructors
extern void _jc_java_lang_reflect_UndeclaredThrowableException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_UndeclaredThrowableException$method$_init$3ba429d9416edd46(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *, struct _jc_java_lang_Throwable$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_UndeclaredThrowableException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_UndeclaredThrowableException$method$getUndeclaredThrowable$2bb9d188611e37cb(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_UndeclaredThrowableException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_reflect_UndeclaredThrowableException$method_info$getUndeclaredThrowable$2bb9d188611e37cb;

// Virtual methods structure
struct _jc_java_lang_reflect_UndeclaredThrowableException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Throwable$object	*(*getUndeclaredThrowable$2bb9d188611e37cb)(_jc_env *, struct _jc_java_lang_reflect_UndeclaredThrowableException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_reflect_UndeclaredThrowableException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_reflect_UndeclaredThrowableException$vmethods	java_lang_reflect_UndeclaredThrowableException;
};

// Vtype
struct _jc_java_lang_reflect_UndeclaredThrowableException$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_UndeclaredThrowableException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_refs {
	struct _jc_java_lang_Throwable$object	*undeclaredThrowable;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_UndeclaredThrowableException$refs {
    _jc_java_lang_reflect_UndeclaredThrowableException$sub_refs	java_lang_reflect_UndeclaredThrowableException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_UndeclaredThrowableException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_reflect_UndeclaredThrowableException$sub_nonrefs	java_lang_reflect_UndeclaredThrowableException;
};

// Object instance structure
struct _jc_java_lang_reflect_UndeclaredThrowableException$object {
	_jc_java_lang_reflect_UndeclaredThrowableException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_UndeclaredThrowableException$vtype	*vtype;
	_jc_java_lang_reflect_UndeclaredThrowableException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_UndeclaredThrowableException$vtype _jc_java_lang_reflect_UndeclaredThrowableException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_UndeclaredThrowableException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_UndeclaredThrowableException$class_object;

#endif	/* _JC_java_lang_reflect_UndeclaredThrowableException_H_ */
